# Invidious.py
A Python wrapper for Invidious API

# Installation
```pip install invidious.py```

# Links
* PyPi: `https://pypi.org/project/invidious.py/`
* Git repo: `https://notabug.org/loliconshik3/invidious.py`
* Matrix: `https://matrix.to/#/#cgwbr:matrix.org`